pub trait FastDeepClone: DeepClone<Fast> {
// Required method
fn fast_deep_clone(&self) -> Self;
}Expand description
Quickly get deep clones of a value, which do not share any semantically-important mutable state.
See DeepClone for more.
Required Methods
Sourcefn fast_deep_clone(&self) -> Self
fn fast_deep_clone(&self) -> Self
Get a deep clone of a value, which does not share any semantically-important mutable state.
The goal is that the clone and its source appear to act completely independently, at least from their public interfaces; mutating or dropping one clone (among possible actions) should have no potentially-observable effect on any other deep clone.
See DeepClone for more.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.