pub trait FastMirroredClone: MirroredClone<Fast> {
// Required method
fn fast_mirrored_clone(&self) -> Self;
}Expand description
Quickly get clones that share all semantically-important mutable state.
See MirroredClone for more.
Required Methods
Sourcefn fast_mirrored_clone(&self) -> Self
fn fast_mirrored_clone(&self) -> Self
Get a clone that shares all semantically-important mutable state with its source.
The goal is that mutating one mirrored clone affects every clone. Different mirrored clones should, from their public interfaces, act identically, with some exceptions like memory addresses.
See MirroredClone for more.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.